<?php
/**
 * SSO Module
 * This class is responsible for SSO module.
 * This is used to define internationalization, admin-specific hooks, and public-facing site hooks for SSO module.
 *
 * @link       http://edwiser.org
 * @since      3.0.0
 * @package    Edwiser Bridge Pro
 */

namespace app\wisdmlabs\edwiserBridgePro\includes\sso;

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'This is not the way to call me!' );
}

/**
 * SSO_Gp_User_Manager class.
 *
 * @package EdwiserBridgePro/includes/sso
 */
class Sso_Gp_User_Manager {
	/**
	 * Plugin name.
	 *
	 * @var string
	 */
	private $plugin_name;

	/**
	 * Plugin version.
	 *
	 * @var string
	 */
	private $version;

	/**
	 * Google Client.
	 *
	 * @var string
	 */
	private $google_client;

	/**
	 * Google Oauth2 Service.
	 *
	 * @var string
	 */
	private $g_oauth2_service;

	/**
	 * Logger.
	 *
	 * @var string
	 */
	private $eb_logger;

	/**
	 * Constructor.
	 *
	 * @param string $lugin_name Plugin name.
	 * @param string $version    Plugin version.
	 */
	public function __construct( $lugin_name, $version ) {
		$this->lugin_name       = $lugin_name;
		$this->version          = $version;
		$this->eb_logger        = \app\wisdmlabs\edwiserBridge\edwiser_bridge_instance();
		$this->google_client    = Sso_Google_Plus_Init::get_google_client();
		$this->g_oauth2_service = Sso_Google_Plus_Init::get_google_oauth2_service();
	}

	/**
	 * Login with google.
	 */
	public function google_login() {

		$user_data = null;
		try {
			if ( isset( $_GET['code'] ) ) { // @codingStandardsIgnoreLine
				$this->google_client->authenticate( $_GET['code'] ); // @codingStandardsIgnoreLine
				$_SESSION['token'] = $this->google_client->getAccessToken();
			} else {
				return;
			}

			if ( isset( $_SESSION['token'] ) ) {
				try {
					$this->google_client->setAccessToken( $_SESSION['token'] );
				} catch ( Exception $e ) {
					$this->eb_logger->logger()->add( 'SSO Log: Google OAuth login access token exception' . serialize( $e->getMessage() ) ); // @codingStandardsIgnoreLine
				}
			}
			if ( $this->google_client->getAccessToken() ) {
				try {
					// Get user profile data from google.
					$gp_user_profile = $this->g_oauth2_service->userinfo->get();
					$gp_user_data    = array(
						'oauth_provider' => 'google',
						'oauth_uid'      => getArrayDataByIndex( $gp_user_profile, 'id' ),
						'first_name'     => getArrayDataByIndex( $gp_user_profile, 'given_name' ),
						'last_name'      => getArrayDataByIndex( $gp_user_profile, 'family_name' ),
						'email'          => getArrayDataByIndex( $gp_user_profile, 'email' ),
						'gender'         => getArrayDataByIndex( $gp_user_profile, 'gender' ),
						'locale'         => getArrayDataByIndex( $gp_user_profile, 'locale' ),
						'picture'        => getArrayDataByIndex( $gp_user_profile, 'picture' ),
						'link'           => getArrayDataByIndex( $gp_user_profile, 'link' ),
					);
				} catch ( Exception $e ) {
					$this->eb_logger->logger()->add( 'SSO Log: Google OAuth login failed to fetch google OAuth profile data.' . serialize( $e->getMessage() ) ); // @codingStandardsIgnoreLine
					auth_redirect();
					exit();
				}
				$user_manager = new Sso_Social_Login_User_Manager( $this->lugin_name, $this->version );
				$redirect     = $this->get_state();
				$user_data    = $user_manager->check_user_details( $gp_user_data, $redirect );
			}
		} catch ( Exception $e ) {
			$this->eb_logger->logger()->add( 'SSO Log: Google OAuth login failed with exception: ' . serialize( $e->getMessage() ) ); // @codingStandardsIgnoreLine
		}
	}

	/**
	 * Get state.
	 *
	 * @return string
	 */
	private function get_state() {
		if ( isset( $_GET['state'] ) ) { // @codingStandardsIgnoreLine
			$state = base64_decode( $_GET['state'] ); // @codingStandardsIgnoreLine
			$state = json_decode( $state );
			return $state;
		} else {
			return get_site_url();
		}
	}
}
